@@ -6,7 +6,7 @@ use parent qw(Exporter Digest::base);
 
 use MIME::Base64 ();
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 $VERSION = eval $VERSION;
 
 eval {
@@ -25,33 +25,6 @@ our @EXPORT_OK = qw(
     simd_512 simd_512_hex simd_512_base64
 );
 
-# TODO: convert to C.
-sub simd_224_hex  { unpack 'H*', simd_224(@_) }
-sub simd_256_hex  { unpack 'H*', simd_256(@_) }
-sub simd_384_hex  { unpack 'H*', simd_384(@_) }
-sub simd_512_hex  { unpack 'H*', simd_512(@_) }
-
-sub simd_224_base64 {
-    my $b64 = MIME::Base64::encode(simd_224(@_), '');
-    $b64 =~ s/=+$//g;
-    return $b64;
-}
-sub simd_256_base64 {
-    my $b64 = MIME::Base64::encode(simd_256(@_), '');
-    $b64 =~ s/=+$//g;
-    return $b64;
-}
-sub simd_384_base64 {
-    my $b64 = MIME::Base64::encode(simd_384(@_), '');
-    $b64 =~ s/=+$//g;
-    return $b64;
-}
-sub simd_512_base64 {
-    my $b64 = MIME::Base64::encode(simd_512(@_), '');
-    $b64 =~ s/=+$//g;
-    return $b64;
-}
-
 sub add_bits {
     my ($self, $data, $bits) = @_;
     if (2 == @_) {
@@ -75,8 +48,8 @@ Digest::SIMD - Perl interface to the SIMD digest algorithm
     use Digest::SIMD qw(simd_256 simd_256_hex simd_256_base64);
 
     $digest = simd_256($data);
-    $digest = simd_hex_256($data);
-    $digest = simd_base64_256($data);
+    $digest = simd_256_hex($data);
+    $digest = simd_256_base64($data);
 
     # Object-oriented interface
     use Digest::SIMD;
@@ -157,6 +130,8 @@ Returns the algorithm used by the object.
 
 L<Digest>
 
+L<Task::Digest>
+
 L<http://www.di.ens.fr/~leurent/simd.html>
 
 L<http://en.wikipedia.org/wiki/NIST_hash_function_competition>
